@@ -1,5 +1,6 @@
 from pocsuite3.lib.controller.controller import start
-from pocsuite3.lib.core.common import single_time_warn_message
+from pocsuite3.lib.core.common import single_time_warn_message, encoder_bash_payload, encoder_powershell_payload, \
+    get_host_ipv6
 from pocsuite3.lib.core.data import conf, kb, logger, paths
 from pocsuite3.lib.core.datatype import AttribDict
 from pocsuite3.lib.core.enums import PLUGIN_TYPE, POC_CATEGORY, VUL_TYPE
@@ -35,7 +36,8 @@ __all__ = (
     'ZoomEye', 'Shodan', 'Fofa', 'Censys', 'PHTTPServer', 'REVERSE_PAYLOAD', 'get_listener_ip', 'get_listener_port',
     'get_results', 'init_pocsuite', 'start_pocsuite', 'get_poc_options', 'crawl',
     'OSShellcodes', 'WebShell', 'OptDict', 'OptIP', 'OptPort', 'OptBool', 'OptInteger', 'OptFloat', 'OptString',
-    'OptItems', 'OptDict', 'get_middle_text', 'generate_shellcode_list', 'random_str')
+    'OptItems', 'OptDict', 'get_middle_text', 'generate_shellcode_list', 'random_str', 'encoder_bash_payload',
+    'encoder_powershell_payload', 'get_host_ipv6')
 
 
 def get_listener_ip():
